@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Pg;
 use Carp;
 
-our $VERSION = '1.1';
+our $VERSION = '1.2';
 our $Debug = 0;
 has pg => sub { +{} };
 
@@ -405,6 +405,30 @@ I<qcount>.
 my $one_row = $c->qselect('table_name', {id => 1},
                          { order_by => {desc => 'id'}, limit => 10, offset => 5, columns => qw[id name]});
 
+For more examples see /examples/*
+
+=head2 C<qinsert>
+
+For examples see /examples/* 
+
+=head2 C<qupdate>
+
+For examples see /examples/*
+
+=head2 C<qdelete>
+
+For examples see /examples/*
+
+=head2 C<qcustom>
+
+For examples see /examples/*
+
+=head2 C<qcount>
+
+For examples see /examples/* 
+
+=head2 C<qerror>
+
 For more examples see /examples/* 
 
 =head1 CONFIG
